@@ -500,6 +500,14 @@ static int scan_dir(const char_t* dir, SCAN_OPTIONS* scan_opts)
     {
       _sntprintf(path, YR_MAX_PATH, _T("%s\\%s"), dir, FindFileData.cFileName);
 
+      // If symbolic links must not be followed, and this entry is a symbolic
+      // link, ignore it and continue with the next one.
+      if (!scan_opts->follow_symlinks && 
+          FindFileData.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT) 
+      {
+        continue;
+      }
+
       if (!(FindFileData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY))
       {
         LARGE_INTEGER file_size;
