@@ -30,25 +30,22 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <assert.h>
 #include <stddef.h>
 #include <string.h>
-
-#include <yara/arena.h>
 #include <yara/ahocorasick.h>
+#include <yara/arena.h>
 #include <yara/compiler.h>
 #include <yara/error.h>
-#include <yara/utils.h>
 #include <yara/mem.h>
-
+#include <yara/utils.h>
 
 typedef struct _QUEUE_NODE
 {
   YR_AC_STATE* value;
 
-  struct _QUEUE_NODE*  previous;
-  struct _QUEUE_NODE*  next;
+  struct _QUEUE_NODE* previous;
+  struct _QUEUE_NODE* next;
 
 } QUEUE_NODE;
 
-
 typedef struct _QUEUE
 {
   QUEUE_NODE* head;
@@ -56,23 +53,18 @@ typedef struct _QUEUE
 
 } QUEUE;
 
-
-//
-// _yr_ac_queue_push
-//
-// Pushes a state in a queue.
+////////////////////////////////////////////////////////////////////////////////
+// Pushes an automaton state into the tail of a queue.
 //
 // Args:
-//    QUEUE* queue     - The queue
-//    YR_AC_STATE* state  - The state
+//   queue: Pointer to the queue.
+//   state: Pointer to the state being pushed into the queue.
 //
 // Returns:
-//    ERROR_SUCCESS if succeed or the corresponding error code otherwise.
+//   ERROR_SUCCESS
+//   ERROR_INSUFFICIENT_MEMORY
 //
-
-static int _yr_ac_queue_push(
-    QUEUE* queue,
-    YR_AC_STATE* value)
+static int _yr_ac_queue_push(QUEUE* queue, YR_AC_STATE* state)
 {
   QUEUE_NODE* pushed_node;
 
@@ -83,11 +75,11 @@ static int _yr_ac_queue_push(
 
   pushed_node->previous = queue->tail;
   pushed_node->next = NULL;
-  pushed_node->value = value;
+  pushed_node->value = state;
 
   if (queue->tail != NULL)
     queue->tail->next = pushed_node;
-  else // queue is empty
+  else  // queue is empty
     queue->head = pushed_node;
 
   queue->tail = pushed_node;
@@ -95,21 +87,16 @@ static int _yr_ac_queue_push(
   return ERROR_SUCCESS;
 }
 
-
-//
-// _yr_ac_queue_pop
-//
-// Pops a state from a queue.
+////////////////////////////////////////////////////////////////////////////////
+// Pops an automaton state from the head of a queue.
 //
 // Args:
-//    QUEUE* queue     - The queue
+//   queue: Pointer to the queue.
 //
 // Returns:
-//    Pointer to the poped state.
+//   Pointer to the poped state.
 //
-
-static YR_AC_STATE* _yr_ac_queue_pop(
-    QUEUE* queue)
+static YR_AC_STATE* _yr_ac_queue_pop(QUEUE* queue)
 {
   YR_AC_STATE* result;
   QUEUE_NODE* popped_node;
@@ -122,7 +109,7 @@ static YR_AC_STATE* _yr_ac_queue_pop(
 
   if (queue->head)
     queue->head->previous = NULL;
-  else // queue is empty
+  else  // queue is empty
     queue->tail = NULL;
 
   result = popped_node->value;
@@ -131,43 +118,32 @@ static YR_AC_STATE* _yr_ac_queue_pop(
   return result;
 }
 
-
-//
-// _yr_ac_queue_is_empty
-//
+////////////////////////////////////////////////////////////////////////////////
 // Checks if a queue is empty.
 //
 // Args:
-//    QUEUE* queue     - The queue
+//   queue: Pointer to the queue.
 //
 // Returns:
-//    true if queue is empty, false otherwise.
+//   true if queue is empty, false otherwise.
 //
-
-static int _yr_ac_queue_is_empty(
-    QUEUE* queue)
+static int _yr_ac_queue_is_empty(QUEUE* queue)
 {
   return queue->head == NULL;
 }
 
-
-//
-// _yr_ac_next_state
-//
+////////////////////////////////////////////////////////////////////////////////
 // Given an automaton state and an input symbol, returns the new state
 // after reading the input symbol.
 //
 // Args:
-//    YR_AC_STATE* state     - Automaton state
-//    uint8_t input       - Input symbol
+//    state: Pointer to automaton state.
+//    input: Input symbol.
 //
 // Returns:
 //   Pointer to the next automaton state.
 //
-
-static YR_AC_STATE* _yr_ac_next_state(
-    YR_AC_STATE* state,
-    uint8_t input)
+static YR_AC_STATE* _yr_ac_next_state(YR_AC_STATE* state, uint8_t input)
 {
   YR_AC_STATE* next_state = state->first_child;
 
@@ -182,24 +158,19 @@ static YR_AC_STATE* _yr_ac_next_state(
   return NULL;
 }
 
-
-//
-// _yr_ac_state_create
-//
+////////////////////////////////////////////////////////////////////////////////
 // Creates a new automaton state, the automaton will transition from
 // the given state to the new state after reading the input symbol.
 //
 // Args:
-//   YR_AC_STATE* state  - Origin state
-//   uint8_t input       - Input symbol
+//   state: Pointer to the origin state.
+//   input: Input symbol.
 //
 // Returns:
 //   YR_AC_STATE* pointer to the newly allocated state or NULL in case
 //   of error.
-
-static YR_AC_STATE* _yr_ac_state_create(
-    YR_AC_STATE* state,
-    uint8_t input)
+//
+static YR_AC_STATE* _yr_ac_state_create(YR_AC_STATE* state, uint8_t input)
 {
   YR_AC_STATE* new_state = (YR_AC_STATE*) yr_malloc(sizeof(YR_AC_STATE));
 
@@ -218,13 +189,10 @@ static YR_AC_STATE* _yr_ac_state_create(
   return new_state;
 }
 
-
+////////////////////////////////////////////////////////////////////////////////
+// Destroys an automaton state.
 //
-// _yr_ac_state_destroy
-//
-
-static int _yr_ac_state_destroy(
-    YR_AC_STATE* state)
+static int _yr_ac_state_destroy(YR_AC_STATE* state)
 {
   YR_AC_STATE* child_state = state->first_child;
 
@@ -240,16 +208,13 @@ static int _yr_ac_state_destroy(
   return ERROR_SUCCESS;
 }
 
-
+////////////////////////////////////////////////////////////////////////////////
+// Create failure links for each automaton state.
 //
-// _yr_ac_create_failure_links
+// This function must be called after all the strings have been added to the
+// automaton with yr_ac_add_string.
 //
-// Create failure links for each automaton state. This function must
-// be called after all the strings have been added to the automaton.
-//
-
-static int _yr_ac_create_failure_links(
-    YR_AC_AUTOMATON* automaton)
+static int _yr_ac_create_failure_links(YR_AC_AUTOMATON* automaton)
 {
   YR_AC_STATE* current_state;
   YR_AC_STATE* failure_state;
@@ -281,18 +246,15 @@ static int _yr_ac_create_failure_links(
 
   // Traverse the trie in BFS order calculating the failure link
   // for each state.
-
   while (!_yr_ac_queue_is_empty(&queue))
   {
     current_state = _yr_ac_queue_pop(&queue);
-    match = yr_arena_ref_to_ptr(
-        automaton->arena, &current_state->matches_ref);
+    match = yr_arena_ref_to_ptr(automaton->arena, &current_state->matches_ref);
 
     if (match != NULL)
     {
       // Find the last match in the list of matches.
-      while (match->next != NULL)
-        match = match->next;
+      while (match->next != NULL) match = match->next;
 
       if (match->backtrack > 0)
         match->next = yr_arena_ref_to_ptr(
@@ -315,8 +277,7 @@ static int _yr_ac_create_failure_links(
 
       while (1)
       {
-        temp_state = _yr_ac_next_state(
-            failure_state, transition_state->input);
+        temp_state = _yr_ac_next_state(failure_state, transition_state->input);
 
         if (temp_state != NULL)
         {
@@ -334,8 +295,7 @@ static int _yr_ac_create_failure_links(
             assert(match != NULL);
 
             // Find the last match in the list of matches.
-            while (match->next != NULL)
-              match = match->next;
+            while (match->next != NULL) match = match->next;
 
             match->next = yr_arena_ref_to_ptr(
                 automaton->arena, &temp_state->matches_ref);
@@ -355,28 +315,22 @@ static int _yr_ac_create_failure_links(
             failure_state = failure_state->failure;
           }
         }
-      } // while(1)
+      }  // while(1)
 
       transition_state = transition_state->siblings;
     }
 
-  } // while(!__yr_ac_queue_is_empty(&queue))
+  }  // while(!__yr_ac_queue_is_empty(&queue))
 
   return ERROR_SUCCESS;
 }
 
-
-//
-// _yr_ac_transitions_subset
-//
+////////////////////////////////////////////////////////////////////////////////
 // Returns true if the transitions for state s2 are a subset of the transitions
 // for state s1. In other words, if at state s2 input X is accepted, it must be
 // accepted in s1 too.
 //
-
-static bool _yr_ac_transitions_subset(
-    YR_AC_STATE* s1,
-    YR_AC_STATE* s2)
+static bool _yr_ac_transitions_subset(YR_AC_STATE* s1, YR_AC_STATE* s2)
 {
   uint8_t set[32];
 
@@ -403,17 +357,12 @@ static bool _yr_ac_transitions_subset(
   return true;
 }
 
-
-//
-// _yr_ac_optimize_failure_links
-//
+////////////////////////////////////////////////////////////////////////////////
 // Removes unnecessary failure links.
 //
-
-static int _yr_ac_optimize_failure_links(
-    YR_AC_AUTOMATON* automaton)
+static int _yr_ac_optimize_failure_links(YR_AC_AUTOMATON* automaton)
 {
-  QUEUE queue = { NULL, NULL};
+  QUEUE queue = {NULL, NULL};
 
   // Push root's children.
   YR_AC_STATE* root_state = automaton->root;
@@ -448,16 +397,12 @@ static int _yr_ac_optimize_failure_links(
   return ERROR_SUCCESS;
 }
 
-
-//
-// _yr_ac_find_suitable_transition_table_slot
-//
+////////////////////////////////////////////////////////////////////////////////
 // Find a place within the automaton's transition table where the transitions
 // for the given state can be put. The function first create a bitmask for the
 // state's transition table, then searches for an offset within the automaton's
 // bitmask where the state's bitmask can be put without bit collisions.
 //
-
 static int _yr_ac_find_suitable_transition_table_slot(
     YR_AC_AUTOMATON* automaton,
     YR_ARENA* arena,
@@ -497,39 +442,31 @@ static int _yr_ac_find_suitable_transition_table_slot(
 
   if (*slot > automaton->tables_size - 257)
   {
-      FAIL_ON_ERROR(yr_arena_allocate_zeroed_memory(
-          arena,
-          YR_AC_TRANSITION_TABLE,
-          257 * sizeof(YR_AC_TRANSITION),
-          NULL));
+    FAIL_ON_ERROR(yr_arena_allocate_zeroed_memory(
+        arena, YR_AC_TRANSITION_TABLE, 257 * sizeof(YR_AC_TRANSITION), NULL));
 
-      FAIL_ON_ERROR(yr_arena_allocate_zeroed_memory(
-          arena,
-          YR_AC_STATE_MATCHES_TABLE,
-          257 * sizeof(uint8_t*),
-          NULL));
+    FAIL_ON_ERROR(yr_arena_allocate_zeroed_memory(
+        arena, YR_AC_STATE_MATCHES_TABLE, 257 * sizeof(uint8_t*), NULL));
 
-      size_t bm_len = YR_BITMASK_SIZE(automaton->tables_size) *
-           sizeof(YR_BITMASK);
+    size_t bm_len = YR_BITMASK_SIZE(automaton->tables_size) *
+                    sizeof(YR_BITMASK);
 
-      size_t bm_len_incr = YR_BITMASK_SIZE(257) * sizeof(YR_BITMASK);
+    size_t bm_len_incr = YR_BITMASK_SIZE(257) * sizeof(YR_BITMASK);
 
-      automaton->bitmask = yr_realloc(automaton->bitmask, bm_len + bm_len_incr);
+    automaton->bitmask = yr_realloc(automaton->bitmask, bm_len + bm_len_incr);
 
-      if (automaton->bitmask == NULL)
-        return ERROR_INSUFFICIENT_MEMORY;
+    if (automaton->bitmask == NULL)
+      return ERROR_INSUFFICIENT_MEMORY;
 
-      memset((uint8_t*) automaton->bitmask + bm_len, 0, bm_len_incr);
+    memset((uint8_t*) automaton->bitmask + bm_len, 0, bm_len_incr);
 
-      automaton->tables_size += 257;
+    automaton->tables_size += 257;
   }
 
   return ERROR_SUCCESS;
 }
 
-//
-// _yr_ac_build_transition_table
-//
+////////////////////////////////////////////////////////////////////////////////
 // Builds the transition table for the automaton. The transition table (T) is a
 // large array of 32-bits integers. Each state in the automaton is represented
 // by an index S within the array. The integer stored in T[S] is the failure
@@ -584,9 +521,8 @@ static int _yr_ac_find_suitable_transition_table_slot(
 // +-----------------------+---------+
 //
 // A more detailed description can be found in: http://goo.gl/lE6zG
-
-static int _yr_ac_build_transition_table(
-    YR_AC_AUTOMATON* automaton)
+//
+static int _yr_ac_build_transition_table(YR_AC_AUTOMATON* automaton)
 {
   YR_AC_TRANSITION* t_table;
   uint32_t* m_table;
@@ -596,7 +532,7 @@ static int _yr_ac_build_transition_table(
 
   uint32_t slot;
 
-  QUEUE queue = { NULL, NULL };
+  QUEUE queue = {NULL, NULL};
 
   // Both t_table and m_table have 512 slots initially, which is enough for the
   // root node's transition table.
@@ -706,10 +642,7 @@ static int _yr_ac_build_transition_table(
   return ERROR_SUCCESS;
 }
 
-
-//
-// _yr_ac_print_automaton_state
-//
+////////////////////////////////////////////////////////////////////////////////
 // Prints automaton state for debug purposes. This function is invoked by
 // yr_ac_print_automaton, is not intended to be used stand-alone.
 //
@@ -722,20 +655,23 @@ static void _yr_ac_print_automaton_state(
   YR_AC_MATCH* match;
   YR_AC_STATE* child_state;
 
-  for (int i = 0; i < state->depth; i++)
-    printf(" ");
+  for (int i = 0; i < state->depth; i++) printf(" ");
 
   child_state = state->first_child;
   child_count = 0;
 
-  while(child_state != NULL)
+  while (child_state != NULL)
   {
     child_count++;
     child_state = child_state->siblings;
   }
 
-  printf("%p childs:%d depth:%d failure:%p",
-         state, child_count, state->depth, state->failure);
+  printf(
+      "%p childs:%d depth:%d failure:%p",
+      state,
+      child_count,
+      state->depth,
+      state->failure);
 
   match = yr_arena_ref_to_ptr(automaton->arena, &state->matches_ref);
 
@@ -743,8 +679,7 @@ static void _yr_ac_print_automaton_state(
   {
     printf("\n");
 
-    for (int i = 0; i < state->depth + 1; i++)
-      printf(" ");
+    for (int i = 0; i < state->depth + 1; i++) printf(" ");
 
     printf("%s = ", match->string->identifier);
 
@@ -783,23 +718,17 @@ static void _yr_ac_print_automaton_state(
 
   child_state = state->first_child;
 
-  while(child_state != NULL)
+  while (child_state != NULL)
   {
     _yr_ac_print_automaton_state(automaton, child_state);
     child_state = child_state->siblings;
   }
 }
 
-
-//
-// yr_ac_automaton_create
-//
+////////////////////////////////////////////////////////////////////////////////
 // Creates a new automaton
 //
-
-int yr_ac_automaton_create(
-    YR_ARENA* arena,
-    YR_AC_AUTOMATON** automaton)
+int yr_ac_automaton_create(YR_ARENA* arena, YR_AC_AUTOMATON** automaton)
 {
   YR_AC_AUTOMATON* new_automaton;
   YR_AC_STATE* root_state;
@@ -832,15 +761,10 @@ int yr_ac_automaton_create(
   return ERROR_SUCCESS;
 }
 
-
-//
-// yr_ac_automaton_destroy
-//
+////////////////////////////////////////////////////////////////////////////////
 // Destroys automaton
 //
-
-int yr_ac_automaton_destroy(
-    YR_AC_AUTOMATON* automaton)
+int yr_ac_automaton_destroy(YR_AC_AUTOMATON* automaton)
 {
   _yr_ac_state_destroy(automaton->root);
 
@@ -850,14 +774,10 @@ int yr_ac_automaton_destroy(
   return ERROR_SUCCESS;
 }
 
-
-//
-// yr_ac_add_string
-//
+////////////////////////////////////////////////////////////////////////////////
 // Adds a string to the automaton. This function is invoked once for each
 // string defined in the rules.
 //
-
 int yr_ac_add_string(
     YR_AC_AUTOMATON* automaton,
     YR_STRING* string,
@@ -919,29 +839,20 @@ int yr_ac_add_string(
   return ERROR_SUCCESS;
 }
 
-
-//
-// yr_ac_compile
-//
+////////////////////////////////////////////////////////////////////////////////
 // Compiles the Aho-Corasick automaton, the resulting data structures are
 // are written in the provided arena.
 //
-
-int yr_ac_compile(
-    YR_AC_AUTOMATON* automaton,
-    YR_ARENA* arena)
+int yr_ac_compile(YR_AC_AUTOMATON* automaton, YR_ARENA* arena)
 {
   FAIL_ON_ERROR(_yr_ac_create_failure_links(automaton));
   FAIL_ON_ERROR(_yr_ac_optimize_failure_links(automaton));
   FAIL_ON_ERROR(_yr_ac_build_transition_table(automaton));
-  
+
   return ERROR_SUCCESS;
 }
 
-
-//
-// yr_ac_print_automaton
-//
+////////////////////////////////////////////////////////////////////////////////
 // Prints automaton for debug purposes.
 //
 void yr_ac_print_automaton(YR_AC_AUTOMATON* automaton)
@@ -950,4 +861,3 @@ void yr_ac_print_automaton(YR_AC_AUTOMATON* automaton)
   _yr_ac_print_automaton_state(automaton, automaton->root);
   printf("-------------------------------------------------------\n");
 }
-
