@@ -30,6 +30,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <yara/globals.h>
 #include <yara/mem.h>
 #include <yara/modules.h>
+#include <yara/strutils.h>
 
 #include "../crypto.h"
 
@@ -266,7 +267,7 @@ define_function(data_md5)
 
   bool past_first_block = false;
 
-  YR_SCAN_CONTEXT* context = scan_context();
+  YR_SCAN_CONTEXT* context = yr_scan_context();
   YR_MEMORY_BLOCK* block = first_memory_block(context);
   YR_MEMORY_BLOCK_ITERATOR* iterator = context->iterator;
 
@@ -303,7 +304,7 @@ define_function(data_md5)
     return_string(YR_UNDEFINED);
   }
 
-  cached_ascii_digest = get_from_cache(module(), "md5", arg_offset, arg_length);
+  cached_ascii_digest = get_from_cache(yr_module(), "md5", arg_offset, arg_length);
 
   if (cached_ascii_digest != NULL)
   {
@@ -325,7 +326,7 @@ define_function(data_md5)
 
     if (offset >= block->base && offset < block->base + block->size)
     {
-      const uint8_t* block_data = block->fetch_data(block);
+      const uint8_t* block_data = yr_fetch_block_data(block);
 
       if (block_data != NULL)
       {
@@ -360,7 +361,7 @@ define_function(data_md5)
       return_string(YR_UNDEFINED);
     }
 
-    if (block->base + block->size > offset + length)
+    if (block->base + block->size >= offset + length)
       break;
   }
 
@@ -380,7 +381,7 @@ define_function(data_md5)
   digest_to_ascii(digest, digest_ascii, YR_MD5_LEN);
 
   FAIL_ON_ERROR(
-      add_to_cache(module(), "md5", arg_offset, arg_length, digest_ascii));
+      add_to_cache(yr_module(), "md5", arg_offset, arg_length, digest_ascii));
 
   YR_DEBUG_FPRINTF(2, stderr, "} // %s() = 0x%s\n", __FUNCTION__, digest_ascii);
   return_string(digest_ascii);
@@ -402,7 +403,7 @@ define_function(data_sha1)
   int64_t offset = arg_offset;
   int64_t length = arg_length;
 
-  YR_SCAN_CONTEXT* context = scan_context();
+  YR_SCAN_CONTEXT* context = yr_scan_context();
   YR_MEMORY_BLOCK* block = first_memory_block(context);
   YR_MEMORY_BLOCK_ITERATOR* iterator = context->iterator;
 
@@ -434,7 +435,7 @@ define_function(data_sha1)
   }
 
   cached_ascii_digest = get_from_cache(
-      module(), "sha1", arg_offset, arg_length);
+      yr_module(), "sha1", arg_offset, arg_length);
 
   if (cached_ascii_digest != NULL)
   {
@@ -455,7 +456,7 @@ define_function(data_sha1)
     // if desired block within current block
     if (offset >= block->base && offset < block->base + block->size)
     {
-      const uint8_t* block_data = block->fetch_data(block);
+      const uint8_t* block_data = yr_fetch_block_data(block);
 
       if (block_data != NULL)
       {
@@ -489,7 +490,7 @@ define_function(data_sha1)
       return_string(YR_UNDEFINED);
     }
 
-    if (block->base + block->size > offset + length)
+    if (block->base + block->size >= offset + length)
       break;
   }
 
@@ -509,7 +510,7 @@ define_function(data_sha1)
   digest_to_ascii(digest, digest_ascii, YR_SHA1_LEN);
 
   FAIL_ON_ERROR(
-      add_to_cache(module(), "sha1", arg_offset, arg_length, digest_ascii));
+      add_to_cache(yr_module(), "sha1", arg_offset, arg_length, digest_ascii));
 
   YR_DEBUG_FPRINTF(2, stderr, "} // %s() = 0x%s\n", __FUNCTION__, digest_ascii);
   return_string(digest_ascii);
@@ -531,7 +532,7 @@ define_function(data_sha256)
   int64_t offset = arg_offset;
   int64_t length = arg_length;
 
-  YR_SCAN_CONTEXT* context = scan_context();
+  YR_SCAN_CONTEXT* context = yr_scan_context();
   YR_MEMORY_BLOCK* block = first_memory_block(context);
   YR_MEMORY_BLOCK_ITERATOR* iterator = context->iterator;
 
@@ -563,7 +564,7 @@ define_function(data_sha256)
   }
 
   cached_ascii_digest = get_from_cache(
-      module(), "sha256", arg_offset, arg_length);
+      yr_module(), "sha256", arg_offset, arg_length);
 
   if (cached_ascii_digest != NULL)
   {
@@ -584,7 +585,7 @@ define_function(data_sha256)
     // if desired block within current block
     if (offset >= block->base && offset < block->base + block->size)
     {
-      const uint8_t* block_data = block->fetch_data(block);
+      const uint8_t* block_data = yr_fetch_block_data(block);
 
       if (block_data != NULL)
       {
@@ -617,7 +618,7 @@ define_function(data_sha256)
       return_string(YR_UNDEFINED);
     }
 
-    if (block->base + block->size > offset + length)
+    if (block->base + block->size >= offset + length)
       break;
   }
 
@@ -637,7 +638,7 @@ define_function(data_sha256)
   digest_to_ascii(digest, digest_ascii, YR_SHA256_LEN);
 
   FAIL_ON_ERROR(
-      add_to_cache(module(), "sha256", arg_offset, arg_length, digest_ascii));
+      add_to_cache(yr_module(), "sha256", arg_offset, arg_length, digest_ascii));
 
   YR_DEBUG_FPRINTF(2, stderr, "} // %s() = 0x%s\n", __FUNCTION__, digest_ascii);
   return_string(digest_ascii);
@@ -656,7 +657,7 @@ define_function(data_checksum32)
       offset,
       length);
 
-  YR_SCAN_CONTEXT* context = scan_context();
+  YR_SCAN_CONTEXT* context = yr_scan_context();
   YR_MEMORY_BLOCK* block = first_memory_block(context);
   YR_MEMORY_BLOCK_ITERATOR* iterator = context->iterator;
 
@@ -673,7 +674,7 @@ define_function(data_checksum32)
   {
     if (offset >= block->base && offset < block->base + block->size)
     {
-      const uint8_t* block_data = block->fetch_data(block);
+      const uint8_t* block_data = yr_fetch_block_data(block);
 
       if (block_data != NULL)
       {
@@ -702,7 +703,7 @@ define_function(data_checksum32)
       return_integer(YR_UNDEFINED);
     }
 
-    if (block->base + block->size > offset + length)
+    if (block->base + block->size >= offset + length)
       break;
   }
 
@@ -740,7 +741,7 @@ define_function(data_crc32)
   int64_t length = integer_argument(2);  // length of bytes we want hash on
   uint32_t checksum = 0xFFFFFFFF;
 
-  YR_SCAN_CONTEXT* context = scan_context();
+  YR_SCAN_CONTEXT* context = yr_scan_context();
   YR_MEMORY_BLOCK* block = first_memory_block(context);
   YR_MEMORY_BLOCK_ITERATOR* iterator = context->iterator;
 
@@ -764,7 +765,7 @@ define_function(data_crc32)
   {
     if (offset >= block->base && offset < block->base + block->size)
     {
-      const uint8_t* block_data = block->fetch_data(block);
+      const uint8_t* block_data = yr_fetch_block_data(block);
 
       if (block_data != NULL)
       {
@@ -795,7 +796,7 @@ define_function(data_crc32)
       return_integer(YR_UNDEFINED);
     }
 
-    if (block->base + block->size > offset + length)
+    if (block->base + block->size >= offset + length)
       break;
   }
 
